#!/bin/sh
# If the user already has a host.def, then we don't
# want to mess with that:
if [ ! -r usr/X11R6/lib/X11/config/host.def ]; then
  echo > usr/X11R6/lib/X11/config/host.def
fi
( cd usr/X11R6/lib ; rm -rf pkgconfig )
( cd usr/X11R6/lib ; ln -sf ../../lib/pkgconfig pkgconfig )
( cd usr/include ; rm -rf GL )
( cd usr/include ; ln -sf /usr/X11R6/include/GL GL )
( cd usr/include ; rm -rf freetype )
( cd usr/include ; ln -sf freetype2/freetype freetype )
